.. _pyramid_jinja2_api:

:mod:`pyramid_jinja2` API
-------------------------

.. automodule:: pyramid_jinja2

.. autofunction:: includeme

.. autoclass:: Jinja2TemplateRenderer
.. autoclass:: SmartAssetSpecLoader
